@@ -2,7 +2,9 @@ use macroquad::prelude::*;
 
 #[macroquad::main("Text")]
 async fn main() {
-    let font = load_ttf_font("./examples/DancingScriptRegular.ttf").await;
+    let font = load_ttf_font("./examples/DancingScriptRegular.ttf")
+        .await
+        .unwrap();
 
     loop {
         clear_background(BLACK);
