@@ -31,7 +31,7 @@ pub use crate::hash;
 
 pub(crate) use render::ElementState;
 
-use std::ops::DerefMut;
+use std::{borrow::Cow, ops::DerefMut};
 
 /// Root UI. Widgets drawn with the root ui will be always presented at the end of the frame with a "default" camera.
 /// UI space would be a "default" screen space (0..screen_width(), 0..screen_height())
@@ -80,6 +80,29 @@ use input::{InputCharacter, Key};
 
 pub type Id = u64;
 
+pub enum UiContent<'a> {
+    Label(Cow<'a, str>),
+    Texture(crate::texture::Texture2D),
+}
+
+impl<'a> From<&'a str> for UiContent<'a> {
+    fn from(data: &'a str) -> UiContent<'a> {
+        UiContent::Label(data.into())
+    }
+}
+
+impl From<String> for UiContent<'static> {
+    fn from(data: String) -> UiContent<'static> {
+        UiContent::Label(data.into())
+    }
+}
+
+impl From<crate::texture::Texture2D> for UiContent<'static> {
+    fn from(data: crate::texture::Texture2D) -> UiContent<'static> {
+        UiContent::Texture(data)
+    }
+}
+
 pub(crate) struct Window {
     pub id: Id,
     pub parent: Option<Id>,
@@ -972,7 +995,7 @@ impl Ui {
         // so need to figure the root id
 
         if self.in_modal {
-            return true;
+            true
         } else {
             self.child_window_stack
                 .get(0)
@@ -1002,7 +1025,7 @@ impl Ui {
             }
         }
 
-        return false;
+        false
     }
 
     pub fn new_frame(&mut self, delta: f32) {
@@ -1184,7 +1207,7 @@ pub(crate) mod ui_context {
             let shift = is_key_down(KeyCode::LeftShift) || is_key_down(KeyCode::RightShift);
             let ctrl = is_key_down(KeyCode::LeftControl) || is_key_down(KeyCode::RightControl);
 
-            while let Some(c) = get_char_pressed() {
+            while let Some(c) = get_char_pressed_ui() {
                 if ctrl == false {
                     ui.char_event(c, false, false);
                 }
